- attribute
Target attribute name for model building
- slevels
List of possible values for classification target
- hidden_layer_sizes
Number of neurons in each hidden layer
- activation
Activation function for hidden layer ('identity', 'logistic', 'tanh', 'relu')
- solver
The solver for weight optimization ('lbfgs', 'sgd', 'adam')
- alpha
L2 penalty (regularization term) parameter
- batch_size
Size of minibatches for stochastic optimizers
- learning_rate
Learning rate schedule for weight updates
- learning_rate_init
Initial learning rate used
- power_t
Exponent for inverse scaling learning rate
- max_iter
Maximum number of iterations
- shuffle
Whether to shuffle samples in each iteration
- random_state
Seed for random number generation
- tol
Tolerance for optimization
- verbose
Whether to print progress messages to stdout
- warm_start
Whether to reuse previous solution
- momentum
Momentum for gradient descent update
- nesterovs_momentum
Whether to use Nesterov's momentum
- early_stopping
Whether to use early stopping
- validation_fraction
Proportion of training data for validation
- beta_1
Exponential decay rate for estimates of first moment vector
- beta_2
Exponential decay rate for estimates of second moment vector
- epsilon
Value for numerical stability in adam
- n_iter_no_change
Maximum number of epochs to not meet tol improvement
- max_fun
Maximum number of loss function calls